@@ -871,7 +871,7 @@ def _copy_object(context, bucket, source_file, destination_file):
     s3_client = boto3.client('s3', aws_access_key_id=credentials.access_key_id,
                              aws_secret_access_key=credentials.secret_access_key, region_name='us-east-1', endpoint_url = context.endpoint_url)
 
-    response = yield _get_object(context, context.s3_bucket, source_file)
+    response = yield _get_object(context, context.s3_bucket, _key(context, source_file))
     file_bytes = response['Body'].read()
     response = yield _save_any(context, None, file_bytes, _key(context, destination_file), 'notebook', None)
     return response
